==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+88"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>ビットマップとしてエクスポート</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>ビットマップファイルの生成中にエラー &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>ビットマップファイルはエクスポートされました &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>ビットマップエクスポート</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>図面単位あたりのピクセル数:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>余白:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;m ビットマップエクスポート...</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>ビットマップとしてエクスポート</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>ビットマップファイルの生成中にエラー &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>ビットマップファイルはエクスポートされました &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>ビットマップエクスポート</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>図面単位あたりのピクセル数:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>余白:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;m ビットマップエクスポート...</translation>
    </message>
</context>
</TS>
